# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/garfield/4wd/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Garfield\\4wd\\": "packages/garfield/4wd/src",
            "Garfield\\4wd\\Seeders\\": "packages/garfield/4wd/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Garfield\4wd\Providers\4wdServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        '4wd'  => Garfield\4wd\Facades\4wd::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Garfield\\4wd\\Seeders\\4wdTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Garfield\4wd\Providers\4wdServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Garfield\4wd\Providers\4wdServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Garfield\4wd\Providers\4wdServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/4wd/{modulename}

**User**

    http://path-to-route-folder/user/4wd/{modulename}

**Public**

    http://path-to-route-folder/4wds


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/4wd/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/4wd/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/4wd/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/4wd/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/4wd/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/4wd/{modulename}/{slug}
    METHOD: GET